﻿namespace Section4_8.ViewModels
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Windows;
    using YKToolkit.Bindings;

    public class MainViewModel : NotificationObject
    {
        /// <summary>
        /// 新しいインスタンスを生成します。
        /// </summary>
        public MainViewModel()
        {
            UpdateGraphData();
        }

        private IEnumerable<Point> data1;
        /// <summary>
        /// 1 つ目のサンプルデータのデータ列を取得または設定します。
        /// </summary>
        public IEnumerable<Point> Data1
        {
            get { return data1; }
            set { SetProperty(ref data1, value); }
        }

        private IEnumerable<Point> data2;
        /// <summary>
        /// 2 つ目のサンプルデータのデータ列を取得または設定します。
        /// </summary>
        public IEnumerable<Point> Data2
        {
            get { return data2; }
            set { SetProperty(ref data2, value); }
        }

        private IEnumerable<Point> data3;
        /// <summary>
        /// 3 つ目のサンプルデータのデータ列を取得または設定します。
        /// </summary>
        public IEnumerable<Point> Data3
        {
            get { return data3; }
            set { SetProperty(ref data3, value); }
        }

        private DelegateCommand updateCommand;
        /// <summary>
        /// グラフデータ更新コマンドを取得します。
        /// </summary>
        public DelegateCommand UpdateCommand
        {
            get
            {
                return updateCommand ?? (updateCommand = new DelegateCommand(_ =>
                {
                    UpdateGraphData();
                }));
            }
        }

        /// <summary>
        /// グラフデータを更新します。
        /// </summary>
        private void UpdateGraphData()
        {
            var rnd = new Random();
            var N = 1001;
            var fMax = 15.0;
            double f;

            f = rnd.NextDouble() * fMax;
            Data1 = Enumerable.Range(0, N).Select(i =>
            {
                // f[Hz] の正弦波
                var x = (double)i;
                var y = 10.0 * Math.Sin(2.0 * Math.PI * f * x / 1000.0);
                return new Point(x, y);
            });

            f = rnd.NextDouble() * fMax;
            Data2 = Enumerable.Range(0, N).Select(i =>
            {
                // f[Hz] で π/4 だけ位相がずれた正弦波
                var x = (double)i;
                var y = 10.0 * Math.Sin(2.0 * Math.PI * f * x / 1000.0 + Math.PI / 4.0);
                return new Point(x, y);
            });

            f = rnd.NextDouble() * fMax;
            double d = 0.0;
            Data3 = Enumerable.Range(0, N).Select(i =>
            {
                // 矩形波
                if (i % (int)(f * 10.0) == 0)
                    d = d > 0.0 ? 0.0 : 64.0;
                var x = (double)i;
                var y = d;
                return new Point(x, y);
            });
        }
    }
}
