﻿namespace Section4_9.ViewModels
{
    using YKToolkit.Bindings;
    using YKToolkit.Controls;

    public class MainViewModel : NotificationObject
    {
        private string okCancelText;
        /// <summary>
        /// OkCancel メッセージボックスの結果を取得します。
        /// </summary>
        public string OkCancelText
        {
            get { return okCancelText ?? "null"; }
            private set { SetProperty(ref okCancelText, value); }
        }

        private string yesNoCancelText;
        /// <summary>
        /// YesNoCancel メッセージボックスの結果を取得します。
        /// </summary>
        public string YesNoCancelText
        {
            get { return yesNoCancelText ?? "null"; }
            private set { SetProperty(ref yesNoCancelText, value); }
        }

        private DelegateCommand okCancelCommand;
        /// <summary>
        /// Ok/Cancel メッセージボックス表示コマンドを取得します。
        /// </summary>
        public DelegateCommand OkCancelCommand
        {
            get
            {
                return okCancelCommand ?? (okCancelCommand = new DelegateCommand(_ =>
                {
                    // ViewModel から Window クラスを呼び出すのは
                    // MVVM 的にはあまり美しいコードではないが
                    // 現実的にはこれが一番楽
                    var result = MessageBox.Show("こんにちは。", "OK か Cancel", MessageBoxButton.OKCancel, MessageBoxImage.Question);
                    OkCancelText = result.ToString();
                }));
            }
        }

        private DelegateCommand yesNoCancelCommand;
        /// <summary>
        /// Yes/No/Cancel メッセージボックス表示コマンドを取得します。
        /// </summary>
        public DelegateCommand YesNoCancelCommand
        {
            get
            {
                return yesNoCancelCommand ?? (yesNoCancelCommand = new DelegateCommand(_ =>
                {
                    // ViewModel から Window クラスを呼び出すのは
                    // MVVM 的にはあまり美しいコードではないが
                    // 現実的にはこれが一番楽
                    var result = MessageBox.Show("さようなら。", "Yes か No か Cancel", MessageBoxButton.YesNoCancel, MessageBoxImage.Warning);
                    YesNoCancelText = result.ToString();
                }));
            }
        }
    }
}
